@@ -1,5 +1,6 @@
 #
 # Imports (JSON library based on import try)
+import sys
 
 from postmark import __version__
 
@@ -7,11 +8,11 @@ try:
     from email.mime.base import MIMEBase
 except ImportError as e:
     from email import MIMEBase
-    from httplib import HTTPConnection
-    from urllib import urlencode
-import sys
+
 if sys.version_info[0] < 3:
     from urllib2 import Request, urlopen, HTTPError, URLError
+    from httplib import HTTPConnection
+    from urllib import urlencode
 else:
     from urllib.request import Request, urlopen
     from urllib.error import HTTPError, URLError
@@ -63,14 +64,15 @@ class PMMail(object):
         bcc:            Who to blind copy the email to, in either
                         "name@email.com" or "First Last <name@email.com>" format
                         Can be multiple values separated by commas (limit 20)
-        subject:        Subject of the email
+        subject:        Subject of the email, ignored if using Postmark templates
         tag:            Use for adding categorizations to your email
         html_body:      Email message in HTML
         text_body:      Email message in plain text
         track_opens:    Whether or not to track if emails were opened or not
         custom_headers: A dictionary of key-value pairs of custom headers.
-        attachments:    A list of tuples or email.mime.base.MIMEBase objects
-                        describing attachments.
+        attachments:    A list of tuples or email.mime.base.MIMEBase objects describing attachments.
+        template_id:    id of Postmark template. See: https://postmarkapp.com/blog/special-delivery-postmark-templates
+        template_model: a dictionary containing the values to be loaded into the template
         '''
         # initialize properties
         self.__api_key = None
@@ -88,6 +90,8 @@ class PMMail(object):
         self.__attachments = []
         self.__message_id = None
         #self.__multipart = False
+        self.__template_id = None
+        self.__template_model = None
 
         acceptable_keys = (
             'api_key',
@@ -103,7 +107,9 @@ class PMMail(object):
             'track_opens',
             'custom_headers',
             'attachments',
-            #'multipart'
+            #'multipart',
+            'template_id',
+            'template_model'
         )
 
         for key in kwargs:
@@ -333,9 +339,12 @@ class PMMail(object):
             raise PMMailMissingValueException('Cannot send an e-mail without a sender (.sender field)')
         elif not self.__to:
             raise PMMailMissingValueException('Cannot send an e-mail without at least one recipient (.to field)')
-        elif not self.__subject:
+        elif (self.__template_id or self.__template_model) and not all([self.__template_id, self.__template_model]):
+            raise PMMailMissingValueException(
+                'Cannot send a template e-mail without a both template_id and template_model set')
+        elif not any([self.__template_id, self.__template_model, self.__subject]):
             raise PMMailMissingValueException('Cannot send an e-mail without a subject')
-        elif not self.__html_body and not self.__text_body:
+        elif not self.__html_body and not self.__text_body and not self.__template_id:
             raise PMMailMissingValueException('Cannot send an e-mail without either an HTML or text version of your e-mail body')
         if self.__track_opens and not self.__html_body:
             print('WARNING: .track_opens set to True with no .html_body set. Tracking opens will not work; message will still send.')
@@ -366,6 +375,12 @@ class PMMail(object):
         if self.__text_body:
             json_message['TextBody'] = self.__text_body
 
+        if self.__template_id:
+            json_message['TemplateId'] = self.__template_id
+
+        if self.__template_model:
+            json_message['TemplateModel'] = self.__template_model
+
         if self.__track_opens:
             json_message['TrackOpens'] = True
 
@@ -440,9 +455,14 @@ class PMMail(object):
             print('JSON message is:\n%s' % json.dumps(json_message, cls=PMJSONEncoder))
             return
 
+        if self.__template_id:
+            endpoint_url = __POSTMARK_URL__ + 'email/withTemplate/'
+        else:
+            endpoint_url = __POSTMARK_URL__ + 'email'
+
         # Set up the url Request
         req = Request(
-            __POSTMARK_URL__ + 'email',
+            endpoint_url,
             json.dumps(json_message, cls=PMJSONEncoder).encode('utf8'),
             {
                 'Accept': 'application/json',
@@ -489,6 +509,7 @@ class PMMail(object):
             else:
                 raise PMMailURLException('URLError: The server couldn\'t fufill the request. (See "inner_exception" for details)', err)
 
+
 # Simple utility that returns a generator to chunk up a list into equal parts
 def _chunks(l, n):
     return (l[i:i+n] for i in range(0, len(l), n))
